@@ -11,8 +11,8 @@ var indexSectionsWithContent =
   8: "abcdefghijklmnopqrstuvwxyz",
   9: "o",
   10: "s",
-  11: "agnsw",
-  12: "ds"
+  11: "agmnsw",
+  12: "dls"
 };
 
 var indexSectionNames =
